@@ -24,14 +24,14 @@
  *
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <glib/gstdio.h>
-#include <config.h>
 
-#include <telepathy-glib/svc-generic.h>
-#include <telepathy-glib/gtypes.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #include "mcd-account.h"
 #include "mcd-account-priv.h"
@@ -49,13 +49,15 @@ store_condition (gpointer key, gpointer value, gpointer userdata)
     gchar condition_key[256];
 
     g_snprintf (condition_key, sizeof (condition_key), "condition-%s", name);
-    mcd_storage_set_string (storage, account_name, condition_key, condition,
-                            FALSE);
+    mcd_storage_set_string (storage, account_name, condition_key, condition);
 }
 
 static gboolean
-set_condition (TpSvcDBusProperties *self, const gchar *name,
-               const GValue *value, GError **error)
+set_condition (TpSvcDBusProperties *self,
+               const gchar *name,
+               const GValue *value,
+               McdDBusPropSetFlags flags,
+               GError **error)
 {
     McdAccount *account = MCD_ACCOUNT (self);
     McdStorage *storage = _mcd_account_get_storage (account);
@@ -67,7 +69,7 @@ set_condition (TpSvcDBusProperties *self, const gchar *name,
 
     if (!G_VALUE_HOLDS (value, TP_HASH_TYPE_STRING_STRING_MAP))
     {
-        g_set_error (error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+        g_set_error (error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
                      "Expected a{s:s} for Condition, but got %s",
                      G_VALUE_TYPE_NAME (value));
         return FALSE;
@@ -75,7 +77,7 @@ set_condition (TpSvcDBusProperties *self, const gchar *name,
 
     if (_mcd_account_get_always_on (account))
     {
-        g_set_error (error, TP_ERRORS, TP_ERROR_PERMISSION_DENIED,
+        g_set_error (error, TP_ERROR, TP_ERROR_PERMISSION_DENIED,
                      "Account %s conditions cannot be changed",
                      mcd_account_get_unique_name (account));
         return FALSE;
@@ -84,21 +86,24 @@ set_condition (TpSvcDBusProperties *self, const gchar *name,
     conditions = g_value_get_boxed (value);
 
     /* first, delete existing conditions */
-    keys = mcd_storage_dup_settings (storage, account_name, NULL);
+    keys = mcd_storage_dup_attributes (storage, account_name, NULL);
 
     for (key = keys; *key != NULL; key++)
     {
         if (strncmp (*key, "condition-", 10) != 0)
             continue;
 
-        mcd_storage_set_value (storage, account_name, *key, NULL, FALSE);
+        mcd_storage_set_attribute (storage, account_name, *key, NULL);
     }
 
     g_strfreev (keys);
 
-    g_hash_table_foreach (conditions, store_condition, account);
+    if (!(flags & MCD_DBUS_PROP_SET_FLAG_ALREADY_IN_STORAGE))
+    {
+        g_hash_table_foreach (conditions, store_condition, account);
 
-    mcd_storage_commit (storage, account_name);
+        mcd_storage_commit (storage, account_name);
+    }
 
     return TRUE;
 }
@@ -136,7 +141,7 @@ GHashTable *mcd_account_get_conditions (McdAccount *account)
     conditions = g_hash_table_new_full (g_str_hash, g_str_equal,
 					g_free, g_free);
 
-    keys = mcd_storage_dup_settings (storage, account_name, NULL);
+    keys = mcd_storage_dup_attributes (storage, account_name, NULL);
 
     for (key = keys; *key != NULL; key++)
     {
